// ./routes/customer.js
const express = require('express');
const router = express.Router();
const bookingController = require('../controllers/bookingController');
const { checkCustomer } = require('../middleware/authMiddleware');

// หน้า appointment
router.get('/appointment', checkCustomer, bookingController.getAppointmentPage);
router.get('/searchService', checkCustomer, bookingController.searchService);
// เส้นทางจอง เมื่อกดปุ่ม "จองเลย"
router.post('/bookNow', checkCustomer, bookingController.bookNow);

// หน้าเลือกเวลา (selectTime)
router.get('/selectTime', checkCustomer, bookingController.getSelectTimePage);

// API สำหรับดึง booking slots ตามวันที่ (ใช้ใน selectTime.ejs)
router.get('/getBookingSlots', checkCustomer, bookingController.getBookingSlots);

// หน้า confirmBooking หลังจากเลือกเวลา (เก็บข้อมูลลง session ก่อนยืนยัน)
router.post('/confirmBooking', checkCustomer, bookingController.confirmBooking);

// เส้นทางสำหรับ completeBooking เมื่อกดยืนยันการจองใน confirmBooking.ejs
router.post('/completeBooking', checkCustomer, bookingController.completeBooking);

// เส้นทางสำหรับแสดงสรุปรายการจอง (bookingSummary.ejs)
// โดยอาจส่ง appointment_id ผ่าน query string เช่น /customer/bookingSummary?id=123
router.get('/bookingSummary', checkCustomer, bookingController.bookingSummary);

router.get('/profile', checkCustomer, (req, res) => {
    res.render('customer/profile');
  });

// หน้าแสดงการจองทั้งหมด
router.get('/allAppointments', checkCustomer, bookingController.getAllAppointmentPage);

// เส้นทางสำหรับยกเลิกการจอง
router.post('/cancelAppointment', checkCustomer, bookingController.cancelAppointment);

// แก้ไขnote หน้า bookingSummary
router.post('/updateNote', checkCustomer, bookingController.updateNote);


module.exports = router;
